"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

const tslib_1 = require("tslib");

const globby_1 = tslib_1.__importDefault(require("globby"));

const getLocaleSpecies_1 = require("./getLocaleSpecies");

const util_1 = require("../../util");

const baseDir = 'locales';
const filePath = 'initReactI18next.ts';
const tpl = 'initReactI18next.tpl';
const defaultLocale = 'zh-CN';
const i18nFilePathName = '@types/react-i18next/index.d.ts';

const writeTypesFile = async api => {
  var _api$userConfig$local;

  return api.generateFile.writeFile({
    path: i18nFilePathName,
    content: api.generateFile.renderTpl(api.generateFile.readTplFile(__dirname, 'index.d.ts.tpl'), {
      initReactI18nextPath: api.resolveConfigAliasNamePath(filePath),
      default: ((_api$userConfig$local = api.userConfig.locale) === null || _api$userConfig$local === void 0 ? void 0 : _api$userConfig$local.default) || defaultLocale
    })
  });
};

const writeFile = async (api, species) => {
  let imports = '';
  let resources = '';
  species.forEach(({
    originName,
    underlineName
  }, index) => {
    imports += `${util_1.spliceImportFrom(underlineName, `@/${baseDir}/${originName}`)}\n`;
    resources += `${index ? '\n' : ''}  '${originName}': {
    translation: ${underlineName},
  },`;
  });
  const {
    locale: localConfig
  } = api.userConfig;
  await api.generateFile.writeFile({
    path: filePath,
    content: api.generateFile.renderTpl(api.generateFile.readTplFile(__dirname, tpl), {
      imports,
      resources,
      default: localConfig === null || localConfig === void 0 ? void 0 : localConfig.default
    })
  });
  return species;
};

async function locale(api) {
  api.describe({
    id: 'locale',
    enable: () => !!api.userConfig.locale,
    onReCompile: enableBy => {
      if (!enableBy) {
        api.generateFile.removeTmpFile(i18nFilePathName);
        api.generateFile.removeTmpFile(filePath);
      }
    }
  });
  api.addDepsEntryExports(() => ({
    source: 'react-i18next'
  }));
  api.addImportToAppEntryFile({
    stage: -9,
    fn: () => ({
      source: api.resolveConfigAliasNamePath(filePath)
    })
  });
  api.addHook({
    key: getLocaleSpecies_1.LOCALE_SPECIES,

    async fn() {
      const files = await globby_1.default(api.resolveSrcPath(`${baseDir}/*.ts`));
      return files.map(f => {
        const originName = util_1.getFileNameFromFilePath(f);
        const underlineName = originName.replace(/-|_|\./g, '');
        return {
          originName,
          underlineName
        };
      });
    }

  });
  api.onGenerateFiles({
    stage: -1,
    fn: async () => {
      const localeSpecies = await getLocaleSpecies_1.getLocaleSpecies(api);
      await writeTypesFile(api);
      return writeFile(api, localeSpecies);
    }
  });
}

exports.default = locale;